@@ -7,6 +7,7 @@ import typer
 
 from lupin_grognard.__init__ import __version__
 from lupin_grognard.core.check import check_commit, check_max_allowed_commits
+from lupin_grognard.core.format.clang_format import ClangFormatter
 from lupin_grognard.core.git import Git
 from .core.tools.utils import (
     create_branch_list,
@@ -19,6 +20,8 @@ from .core.tools.utils import (
 load_dotenv()
 GROG_BRANCHES = os.getenv("GROG_BRANCHES")
 GROG_MAX_ALLOWED_COMMITS = os.getenv("GROG_MAX_ALLOWED_COMMITS")
+GROG_DONT_CHECK_FOR_APPROVERS = os.getenv("GROG_DONT_CHECK_FOR_APPROVERS")
+GROG_CLANG_FORMAT = os.getenv("GROG_CLANG_FORMAT")
 
 
 cli = typer.Typer()
@@ -104,3 +107,15 @@ def check_commits(
                 commits=commit_range_list_to_check,
                 merge_option=grog_dont_check_for_approvers,
             )
+
+
+@cli.command()
+def format(
+    clang_format: str = typer.Option(
+        "clang-format-14", "--clang-format", "-cf", envvar="GROG_CLANG_FORMAT"
+    )
+):
+    """Format C/C++ files with clang-format
+    You can set GROG_CLANG_FORMAT env var in order to configure the executable to be used"""
+    formater = ClangFormatter(name=clang_format)
+    formater.format_c_cpp_files()
